Struct DebouncedEvent

struct DebouncedEvent { ... }

A debounced event.

Does not emit any specific event type on purpose, only distinguishes between an any event and a continuous any event.

Fields

path: PathBuf

Event path

kind: DebouncedEventKind

Event kind

Implementations

impl DebouncedEvent

fn new(path: PathBuf, kind: DebouncedEventKind) -> Self

impl Clone for DebouncedEvent

fn clone(self: &Self) -> DebouncedEvent

impl Debug for DebouncedEvent

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for DebouncedEvent

impl Freeze for DebouncedEvent

impl Hash for DebouncedEvent

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for DebouncedEvent

fn eq(self: &Self, other: &DebouncedEvent) -> bool

impl RefUnwindSafe for DebouncedEvent

impl Send for DebouncedEvent

impl StructuralPartialEq for DebouncedEvent

impl Sync for DebouncedEvent

impl Unpin for DebouncedEvent

impl UnsafeUnpin for DebouncedEvent

impl UnwindSafe for DebouncedEvent

impl<T> Any for DebouncedEvent

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DebouncedEvent

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DebouncedEvent

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DebouncedEvent

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DebouncedEvent

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DebouncedEvent

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DebouncedEvent

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DebouncedEvent

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DebouncedEvent

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>