Enum CreateKind

enum CreateKind

An event describing creation operations on files.

Variants

Any

The catch-all case, to be used when the specific kind of event is unknown.

File

An event which results in the creation of a file.

Folder

An event which results in the creation of a folder.

Other

An event which specific kind is known but cannot be represented otherwise.

Implementations

impl Clone for CreateKind

fn clone(self: &Self) -> CreateKind

impl Copy for CreateKind

impl Debug for CreateKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for CreateKind

impl Freeze for CreateKind

impl Hash for CreateKind

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for CreateKind

fn eq(self: &Self, other: &CreateKind) -> bool

impl RefUnwindSafe for CreateKind

impl Send for CreateKind

impl StructuralPartialEq for CreateKind

impl Sync for CreateKind

impl Unpin for CreateKind

impl UnsafeUnpin for CreateKind

impl UnwindSafe for CreateKind

impl<T> Any for CreateKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for CreateKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for CreateKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for CreateKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for CreateKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for CreateKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for CreateKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for CreateKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for CreateKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>