Enum DataChange

enum DataChange

An event emitted when the data content of a file is changed.

Variants

Any

The catch-all case, to be used when the specific kind of event is unknown.

Size

An event emitted when the size of the data is changed.

Content

An event emitted when the content of the data is changed.

Other

An event which specific kind is known but cannot be represented otherwise.

Implementations

impl Clone for DataChange

fn clone(self: &Self) -> DataChange

impl Copy for DataChange

impl Debug for DataChange

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for DataChange

impl Freeze for DataChange

impl Hash for DataChange

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for DataChange

fn eq(self: &Self, other: &DataChange) -> bool

impl RefUnwindSafe for DataChange

impl Send for DataChange

impl StructuralPartialEq for DataChange

impl Sync for DataChange

impl Unpin for DataChange

impl UnsafeUnpin for DataChange

impl UnwindSafe for DataChange

impl<T> Any for DataChange

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DataChange

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DataChange

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DataChange

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DataChange

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DataChange

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DataChange

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DataChange

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DataChange

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>