Enum MetadataKind
enum MetadataKind
An event emitted when the metadata of a file or folder is changed.
Variants
-
Any The catch-all case, to be used when the specific kind of event is unknown.
-
AccessTime An event emitted when the access time of the file or folder is changed.
-
WriteTime An event emitted when the write or modify time of the file or folder is changed.
-
Permissions An event emitted when the permissions of the file or folder are changed.
-
Ownership An event emitted when the ownership of the file or folder is changed.
-
Extended An event emitted when an extended attribute of the file or folder is changed.
If the extended attribute's name or type is known, it should be provided in the
Infoevent attribute.-
Other An event which specific kind is known but cannot be represented otherwise.
Implementations
impl Clone for MetadataKind
fn clone(self: &Self) -> MetadataKind
impl Copy for MetadataKind
impl Debug for MetadataKind
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for MetadataKind
impl Freeze for MetadataKind
impl Hash for MetadataKind
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for MetadataKind
fn eq(self: &Self, other: &MetadataKind) -> bool
impl RefUnwindSafe for MetadataKind
impl Send for MetadataKind
impl StructuralPartialEq for MetadataKind
impl Sync for MetadataKind
impl Unpin for MetadataKind
impl UnsafeUnpin for MetadataKind
impl UnwindSafe for MetadataKind
impl<T> Any for MetadataKind
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MetadataKind
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MetadataKind
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MetadataKind
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MetadataKind
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for MetadataKind
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for MetadataKind
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MetadataKind
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MetadataKind
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>