Enum ModifyKind

enum ModifyKind

An event describing mutation of content, name, or metadata.

Variants

Any

The catch-all case, to be used when the specific kind of event is unknown.

Data(DataChange)

An event emitted when the data content of a file is changed.

Metadata(MetadataKind)

An event emitted when the metadata of a file or folder is changed.

Name(RenameMode)

An event emitted when the name of a file or folder is changed.

Other

An event which specific kind is known but cannot be represented otherwise.

Implementations

impl Clone for ModifyKind

fn clone(self: &Self) -> ModifyKind

impl Copy for ModifyKind

impl Debug for ModifyKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for ModifyKind

impl Freeze for ModifyKind

impl Hash for ModifyKind

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for ModifyKind

fn eq(self: &Self, other: &ModifyKind) -> bool

impl RefUnwindSafe for ModifyKind

impl Send for ModifyKind

impl StructuralPartialEq for ModifyKind

impl Sync for ModifyKind

impl Unpin for ModifyKind

impl UnsafeUnpin for ModifyKind

impl UnwindSafe for ModifyKind

impl<T> Any for ModifyKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ModifyKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ModifyKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ModifyKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ModifyKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for ModifyKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for ModifyKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ModifyKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ModifyKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>