Enum RemoveKind

enum RemoveKind

An event describing removal operations on files.

Variants

Any

The catch-all case, to be used when the specific kind of event is unknown.

File

An event emitted when a file is removed.

Folder

An event emitted when a folder is removed.

Other

An event which specific kind is known but cannot be represented otherwise.

Implementations

impl Clone for RemoveKind

fn clone(self: &Self) -> RemoveKind

impl Copy for RemoveKind

impl Debug for RemoveKind

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for RemoveKind

impl Freeze for RemoveKind

impl Hash for RemoveKind

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for RemoveKind

fn eq(self: &Self, other: &RemoveKind) -> bool

impl RefUnwindSafe for RemoveKind

impl Send for RemoveKind

impl StructuralPartialEq for RemoveKind

impl Sync for RemoveKind

impl Unpin for RemoveKind

impl UnsafeUnpin for RemoveKind

impl UnwindSafe for RemoveKind

impl<T> Any for RemoveKind

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RemoveKind

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RemoveKind

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for RemoveKind

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for RemoveKind

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for RemoveKind

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for RemoveKind

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RemoveKind

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RemoveKind

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>