Enum RenameMode
enum RenameMode
An event emitted when the name of a file or folder is changed.
Variants
-
Any The catch-all case, to be used when the specific kind of event is unknown.
-
To An event emitted on the file or folder resulting from a rename.
-
From An event emitted on the file or folder that was renamed.
-
Both A single event emitted with both the
FromandTopaths.This event should be emitted when both source and target are known. The paths should be provided in this exact order (from, to).
-
Other An event which specific kind is known but cannot be represented otherwise.
Implementations
impl Clone for RenameMode
fn clone(self: &Self) -> RenameMode
impl Copy for RenameMode
impl Debug for RenameMode
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for RenameMode
impl Freeze for RenameMode
impl Hash for RenameMode
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for RenameMode
fn eq(self: &Self, other: &RenameMode) -> bool
impl RefUnwindSafe for RenameMode
impl Send for RenameMode
impl StructuralPartialEq for RenameMode
impl Sync for RenameMode
impl Unpin for RenameMode
impl UnsafeUnpin for RenameMode
impl UnwindSafe for RenameMode
impl<T> Any for RenameMode
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for RenameMode
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for RenameMode
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for RenameMode
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for RenameMode
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for RenameMode
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for RenameMode
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for RenameMode
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for RenameMode
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>