Enum Flag
enum Flag
Special Notify flag on the event.
This attribute is used to flag certain kinds of events that Notify either marks or generates in particular ways.
Variants
-
Rescan Rescan notices are emitted by some platforms (and may also be emitted by Notify itself). They indicate either a lapse in the events or a change in the filesystem such that events received so far can no longer be relied on to represent the state of the filesystem now.
An application that simply reacts to file changes may not care about this. An application that keeps an in-memory representation of the filesystem will need to care, and will need to refresh that representation directly from the filesystem.
Implementations
impl Clone for Flag
fn clone(self: &Self) -> Flag
impl Copy for Flag
impl Debug for Flag
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Flag
impl Freeze for Flag
impl Hash for Flag
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for Flag
fn eq(self: &Self, other: &Flag) -> bool
impl RefUnwindSafe for Flag
impl Send for Flag
impl StructuralPartialEq for Flag
impl Sync for Flag
impl Unpin for Flag
impl UnsafeUnpin for Flag
impl UnwindSafe for Flag
impl<T> Any for Flag
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Flag
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Flag
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Flag
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Flag
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Flag
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Flag
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Flag
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Flag
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>